# Contributors

The following people have contributed to the development of GatherUp:

<!-- Add your name below, sort alphabetically by surname. Link to Github profile / your home page. -->

- [Neil Stoker](https://github.com/nmstoker)
